package email_message

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Email_message.Email_addressSource

Sourcemodule Domain : sig ... end
include module type of struct include Email_address end with module Domain := Email_address.Domain
val sexp_of_t : t -> Ppx_sexp_conv_lib.Sexp.t
Sourceval create : ?prefix:string -> ?domain:Email_address.Domain.t -> string -> t
Sourceval of_string : ?default_domain:string -> string -> t Core_kernel.Or_error.t
Sourceval of_string_exn : ?default_domain:string -> string -> t
Sourceval list_of_string : ?default_domain:string -> string -> t list Core_kernel.Or_error.t
Sourceval list_of_string_exn : ?default_domain:string -> string -> t list
Sourceval to_string : t -> string
Sourceval list_to_header_value : t list -> string
Sourceval local_part : t -> string
Sourceval set_local_part : t -> string -> t
Sourceval domain : t -> Email_address.Domain.t option
Sourceval set_domain : t -> Email_address.Domain.t option -> t
Sourceval address_part : ?brackets:bool -> ?lowercase_domain:bool -> t -> t
Sourceval address_part_string : ?brackets:bool -> ?lowercase_domain:bool -> t -> string
Sourceval set_address_part : t -> string -> t Core_kernel.Or_error.t

set_address_part expects an email address without prefix or angle brackets e.g. USER@DOMAIN.

Sourceval prefix : t -> string option
Sourceval set_prefix : t -> string option -> t

set_prefix will remove angle brackets if given None, otherwise angle brackets are added before the given prefix.

Sourceval arg_type : t Core_kernel.Command.Arg_type.t
include Core_kernel.Comparable.S_plain with type t := t
include Base.Comparable.S with type t := t
include Base.Comparisons.S with type t := t
include Base.Comparisons.Infix with type t := t
val (>=) : t -> t -> bool
val (<=) : t -> t -> bool
val (=) : t -> t -> bool
val (>) : t -> t -> bool
val (<) : t -> t -> bool
val (<>) : t -> t -> bool
val equal : t -> t -> bool
val min : t -> t -> t
val max : t -> t -> t
val ascending : t -> t -> int

ascending is identical to compare. descending x y = ascending y x. These are intended to be mnemonic when used like List.sort ~compare:ascending and List.sort ~cmp:descending, since they cause the list to be sorted in ascending or descending order, respectively.

val descending : t -> t -> int
val between : t -> low:t -> high:t -> bool

between t ~low ~high means low <= t <= high

val clamp_exn : t -> min:t -> max:t -> t

clamp_exn t ~min ~max returns t', the closest value to t such that between t' ~low:min ~high:max is true.

Raises if not (min <= max).

val clamp : t -> min:t -> max:t -> t Base.Or_error.t
include Base.Comparator.S with type t := t
type comparator_witness = Email_address.comparator_witness
val validate_lbound : min:t Base.Maybe_bound.t -> t Base.Validate.check
val validate_ubound : max:t Base.Maybe_bound.t -> t Base.Validate.check
val validate_bound : min:t Base.Maybe_bound.t -> max:t Base.Maybe_bound.t -> t Base.Validate.check
module Replace_polymorphic_compare = Email_address.Replace_polymorphic_compare
module Map = Email_address.Map
module Set = Email_address.Set
include Core_kernel.Hashable.S_plain with type t := t
val compare : t -> t -> Core_kernel__.Import.int
val hashable : t Base.Hashable.t
module Table = Email_address.Table
module Hash_set = Email_address.Hash_set
module Hash_queue = Email_address.Hash_queue
Sourceval local_address : unit -> t